@@ -146,7 +146,10 @@ create_or_modify_constraint()
 			break
 			;;
 
-		205)	: "205 aka pcmk_err_old_data ==> going to retry in a bit"
+			# see pacemaker commit f7e5558d6 Refactor: all: use consistent exit status codes
+			# Relevant for Pacemaker 2.0+
+			# 103/CRM_EX_OLD is Pacemaker 2, 205 aka pcmk_err_old_data is Pacemaker 1.1
+		103|205)	: "103 aka CRM_EX_OLD, or 205 aka pcmk_err_old_data ==> going to retry in a bit"
 			(( $SECONDS >= $timeout )) && break
 			sleep 1
 			continue
@@ -194,15 +197,25 @@ fence_peer_init()
 {
 	# we know which instance we are: $OCF_RESOURCE_INSTANCE.
 	# but we do not know the xml ID of the <master/> :(
+
+	# with Pacemaker 2, its "promotable clones" instead of the
+	# "master" (which was deemed a bad naming choice).
+	# newer pacemaker does stil understand and may still use the old xml, though,
+	# and it is rather cumbersome to detect which is in use.
+	# just try both
+
 	# cibadmin -Ql --xpath \
 	# '//master[primitive[@type="drbd" and instance_attributes/nvpair[@name = "drbd_resource" and @value="r0"]]]/@id'
 	# but I'd have to pipe that through sed anyways, because @attribute
 	# xpath queries are not supported.
 	# and I'd be incompatible with older cibadmin not supporting --xpath.
-	# be cool, sed it out:
+	# be cool, sed it out.
+	# I could be more strict about primitive class:provider:type,
+	# or double check that it is in fact a promotable="true" clone...
+	# But in the real world, this is good enough.
 	: ${master_id=$(set +x; echo "$cib_xml" |
-		sed -ne '/<master /,/<\/master>/ {
-			   /<master / h;
+		sed -ne '/<\(clone\|master\) /,/<\/\(clone\|master\)>/ {
+			   /<\(clone\|master\) / h;
 			     /<primitive/,/<\/primitive/ {
 			       /<instance_attributes/,/<\/instance_attributes/ {
 				 /<nvpair .*\bname="drbd_resource"/ {
