@@ -39,9 +39,28 @@ remove_constraint()
 }
 
 cib_xml=""
+cib_xml_first_line=""
+crm_feature_set=""
+admin_epoch=""
+epoch=""
+num_updates=""
+have_quorum=""
 get_cib_xml() {
 	cibadmin_invocations=$(( $cibadmin_invocations + 1 ))
 	cib_xml=$( set +x; cibadmin "$@" )
+	cib_xml_first_line=${cib_xml%%>*}
+
+	set -- ${cib_xml_first_line}
+	local x
+	for x ; do
+	case $x in
+	crm_feature_set=*)	x=${x#*'="'}; x=${x%'"'}; crm_feature_set=$x ;;
+	admin_epoch=*)		x=${x#*'="'}; x=${x%'"'}; admin_epoch=$x ;;
+	epoch=*)		x=${x#*'="'}; x=${x%'"'}; epoch=$x ;;
+	num_updates=*)		x=${x#*'="'}; x=${x%'"'}; num_updates=$x ;;
+	have-quorum=*)		x=${x#*'="'}; x=${x%'"'}; have_quorum=$x ;;
+	esac
+	done
 }
 
 
@@ -51,15 +70,25 @@ fence_peer_init()
 {
 	# we know which instance we are: $OCF_RESOURCE_INSTANCE.
 	# but we do not know the xml ID of the <master/> :(
+
+	# with Pacemaker 2, its "promotable clones" instead of the
+	# "master" (which was deemed a bad naming choice).
+	# newer pacemaker does stil understand and may still use the old xml, though,
+	# and it is rather cumbersome to detect which is in use.
+	# just try both
+
 	# cibadmin -Ql --xpath \
 	# '//master[primitive[@type="drbd" and instance_attributes/nvpair[@name = "drbd_resource" and @value="r0"]]]/@id'
 	# but I'd have to pipe that through sed anyways, because @attribute
 	# xpath queries are not supported.
 	# and I'd be incompatible with older cibadmin not supporting --xpath.
-	# be cool, sed it out:
+	# be cool, sed it out.
+	# I could be more strict about primitive class:provider:type,
+	# or double check that it is in fact a promotable="true" clone...
+	# But in the real world, this is good enough.
 	: ${master_id=$(set +x; echo "$cib_xml" |
-		sed -ne '/<master /,/<\/master>/ {
-			   /<master / h;
+		sed -ne '/<\(clone\|master\) /,/<\/\(clone\|master\)>/ {
+			   /<\(clone\|master\) / h;
 			     /<primitive/,/<\/primitive/ {
 			       /<instance_attributes/,/<\/instance_attributes/ {
 				 /<nvpair .*\bname="drbd_resource"/ {
@@ -366,7 +395,7 @@ drbd_peer_fencing()
 {
 	local rc
 	# input to fence_peer_init:
-	# $DRBD_RESOURCE is set by command line of from environment.
+	# $DRBD_RESOURCE is set by command line or from environment.
 	# $id_prefix is set by command line or default.
 	# $master_id is set by command line or will be parsed from the cib.
 	# output of fence_peer_init:
