@@ -19,7 +19,7 @@
 #include <linux/drbd_genl_api.h>
 #include <linux/drbd_limits.h>
 #include "drbd_nla.h"
-#include <linux/genl_magic_func.h>
+#include "linux/genl_magic_func.h"
 #include "drbdtool_common.h"
 #include "config_flags.h"
 
